@@ -44,7 +44,7 @@ class VaultEC2(Vault):
 
             headers = json.dumps(self.headers_to_go_style(dict(request.headers)))
 
-            role_with_environment = ["development"]
+            role_with_environment = ["development","staging","pre-prod"]
 
             if instance_object.tags['environment'] in role_with_environment:
                 role = "{service}-{environment}-{region}".format(
